# Sequences

In an Alda score, a series of [notes](notes.md) or other events can be captured
as a **sequence** by enclosing it in square brackets:

```alda
[c d e f c1/e/g]
```

On its own, this is nothing special; the score is still essentially the same,
and sounds the same. However, capturing a sequence of events allows you to do
special things like [repeat](repeats.md) the sequence several times in a row, or
store it in a [variable](variables.md) and use it later.
